#
# spec file for package apitrace
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           apitrace
Version:        13.0
Release:        1.1
Summary:        Tools for tracing OpenGL
License:        MIT
URL:            https://apitrace.github.io/
Source0:        https://github.com/apitrace/apitrace/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         001-no-submodules.patch
Patch1:         002-no-static-libbacktrace.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.15
BuildRequires:  libbacktrace-devel
BuildRequires:  libdwarf-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(libbrotlienc)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libproc2)
BuildRequires:  pkgconfig(libunwind)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(snappy)
BuildRequires:  pkgconfig(waffle-1)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
Requires:       %{name}-wrappers
Requires:       python3-Pillow
Requires:       python3-curses
Requires:       python3-numpy

%description
apitrace consists of a set of tools to:
- trace OpenGL, OpenGL ES, Direct3D, and DirectDraw APIs calls to a file;
- replay the recorded calls from a file, on any machine and, for OpenGL and OpenGL ES, on any operating system;
- inspect state at any call while replaying;
- view framebuffers and textures;
- view call data;
- edit trace files;
- profile performance of traces;

%package wrappers
Summary:        Tools for tracing OpenGL

%description wrappers
This package contains libs that are preloaded into traced programs.

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} -Wno-error=return-type"
%cmake -DENABLE_STATIC_SNAPPY=OFF -DENABLE_QT6=ON
%cmake_build

%install
%cmake_install
# We're packaging docs in files section
rm -r %{buildroot}%{_datadir}/doc/%{name}

# fix env
%python3_fix_shebang_path %{buildroot}%{_libdir}/%{name}/scripts/*.py

%check
%ctest

%files
%license LICENSE
%doc README.markdown docs/BUGS.markdown docs/NEWS.markdown docs/USAGE.markdown
%dir %{_libdir}/%{name}
%{_bindir}/apitrace
%{_bindir}/eglretrace
%{_bindir}/glretrace
%{_bindir}/gltrim
%{_bindir}/qapitrace
%{_libdir}/%{name}/scripts/

%files wrappers
%{_libdir}/%{name}/wrappers/

%changelog
* Sun Jun 29 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 13.0:
  * Some fixes related to the MRs I opened earlier
  * Add support for GL_EXT_texture_compression_astc_decode_mode
  * Add support for profiling with EXT_disjoint_timer_query
  * Minor fixes and additions to opengl trace
  * OVR_multiview extension support
  * retrace: Use right API calls when using EXT_disjoint_timer_query
  * Explicit header: stdint
  * retrace: Fix GPU Duration calculation
  * specs: Fix pUAVInitialCounts array element count of
  * D3D11DeviceContext::OMSetRenderTargetsAndUnorderedAccessViews
  * fix snappy detection, use build_testing for gtest detection too
  * d3d9retrace: Adjust presentation interval when forcing windowed mode
  * fix qt-6.9
  * D3D8/9: Decode AL16 and R16 FOURCC formats
- update to 12.0:
  * cli: be more verbose about what GL api means on Linux/Mac
  * Fix a crash in retrace_glXChooseFBConfig
  * gltrim: retain objects in the last frame that were created in earlier frames
  * gltrim: handle a few more EGL calls
  * docs: update attachment procedure for trace
  * implement versioning support
  * Submitted handle wgl and more gl45
  * Fix bug in _EGLImageKHR_get_image_info
  * Retrace: Add retrace watchdog flag
  * gui: Address deprecation warnings
  * gui: Add icon
  * d3d8trace: Remap shader handles
  * d3d8trace: Remap state block handles
  * Gltrim skip while looping
  * #848. All three states of GL_ATI_mem_info are int x 4 arrays
  * #848. Check for buffer overflow in case of scalar glGet[Integer]v
  * #850. Add a bit of excessive space in image buffer
  * gltrim: Add option to replace swaps in setup with glFinish
  * Add missing calls to handle the GLES version of GravityMark
  * Add envvar FLUSH_EVERY_MS.
  * wrappers: add noexcept specification to DWriteCreateFactory
  * cmake: enable LTO
  * frametrimmer: split OpenGL implementation into a new class
  * Implement a bunch of additional EGL extensions
  * Bug fix in GUI
  * Improve the layout of the retracer dialog
  * retrace: call waffle_destroy_window on drawable destructor
  * Avoid compilation error with ambiguous QString + QLatin1String
  * gltrim: Fix trimmimg multi-threaded traces and fix a few calls
  * Fake command line arguments during replay, so they match traced program's arguments
  * Fix command line parsing for empty arguments
  * Add option to append timestamp to generated trace filename
  * Add support for EGL_DEBUG_KHR extension
  * Display format modifiers as hexadecimal values
  * Add support for fixed rate compression extensions
- update to 11.1:
  * frametrim: fix active texture check compare
  * gltrim: handle glFramebufferTexture3D and glMultiDrawElements
  * implement ARB_create_context_no_error for GLX and WGL
  * wrappers/glcaps: Check config availablility before dereferencing
- update to 11.0:
  * nothing of relevance
- remove apitrace-fix-glibc-2.34.patch, as upstream fixed the issue
- switch the gui to Qt6
- add patches 001-no-submodules.patch and 002-no-static-libbacktrace.patch,
  as upstream prefers rather to use statically linked dependencies
- don't filter out glibc_private symbols
* Mon Aug 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libprocps) or pkgconfig(libproc2).
* Sat Sep 25 2021 Adam Mizerski <adam@mizerski.pl>
- Added patch apitrace-fix-glibc-2.34.patch
  Fixes building with glibc 2.34. See also
  https://github.com/apitrace/apitrace/issues/756
* Tue Sep 14 2021 Adam Mizerski <adam@mizerski.pl>
- improve packaging
  - remove GLIBC_PRIVATE from generated rpm requires
    (see https://github.com/apitrace/apitrace/issues/258)
  - don't use bundled 'snappy'.
  - don't duplicate license and docs files
* Fri Sep 10 2021 Adam Mizerski <adam@mizerski.pl>
- mention baselibs.conf in spec
* Wed Sep  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 10.0
  * Upstream does not provide a changelog
- Run unit tests
- Package license file and readme
* Mon Jan 27 2020 Adam Mizerski <adam@mizerski.pl>
- new package; version 9.0
